#include <avr/io.h>
#include <avr/interrupt.h>
#include <stdbool.h>
#include <avr/sleep.h>
#include <avr/wdt.h>

void main()
{
    // ACSR // does not need to be set when only checking the output of the comparitor edge
    DDRB = (1 << DDB1); // B1 output
    PORTB = 0;
    wdt_enable(WDTO_2S);
    wdt_reset();

    while(1)
    {
        if (((ACSR & (1<<ACO)) == 0))
        {
            // no detection yet so sleep until watchdog timeout
            // this uses the lowest power mode possible
            set_sleep_mode(SLEEP_MODE_PWR_DOWN);
            sleep_mode(); // since I don't use interrupts this is always safe see avr-gcc sleep for notes when using interrupt
        }

        // comparitor output detect
        // met ADC0 kijken hoe snel de ventilator moet lopen
        ADMUX = (1<<ADLAR); // external reference voltage , left adjust output, mux 0 channel
        ADCSRA = (1<<ADEN) | (1<<ADSC); // enable, start conversion, not free running, 2 prescaling
        while ((ADCSRA & (1<<ADIF)) == 0);
        
        // lees ADC uit en zet de pwm aan
        OCR1A = ADCH;
        ADMUX = 0; // zet adc uit
        ADCSRA = 0;
        //mode 1 -> 0 0 0 1 PWM, Phase Correct, 8-bit 0x00FF TOP BOTTOM
        TCCR1A = (1<<COM1A1)| (1<< WGM10);  // CMO1A1 COM1A0 =10 clear on compare match
        TCCR1B = (1<<CS11) | (1<<CS10); // 1/64 prescaler
        
        while (ACSR & (1<<ACO))
        {
            // binnen de loop bepaal ik nu misschien tijdelijk de setting voor de Fan output
            // dit maak het afstellen wat makkelijker 
            ADMUX = (1<<ADLAR); // external reference voltage , left adjust output, mux 0 channel
            ADCSRA = (1<<ADEN) | (1<<ADSC); // enable, start conversion, not free running, 2 prescaling
            while ((ADCSRA & (1<<ADIF)) == 0);
            
            // lees ADC uit en zet de pwm aan
            OCR1A = ADCH;
            wdt_reset(); // zolang die aan is
        }
        // zet de pwm uit
        OCR1A = 0x0;
        TCCR1A = 0;
        TCCR1B = 0;
    }
}
